NAME = "blue_south"

ICON = "🌀"

DESCRIPTION = f"{ICON} AI for Global South: Free from Big Tech."

VERSION = "4.9.1"

REPO_NAME = "blue-south"

MARQUEE = "https://github.com/kamangir/assets/raw/main/blue-south/marquee.png?raw=true"

ALIAS = "@south"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
